@@ -78,10 +78,13 @@ pub struct AstVariant {
     names: Vec<String>,
 }
 
-impl TailwindInstance for AstStyle {
-    fn id(&self) -> String {
+impl Display for AstStyle {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         todo!()
     }
+}
+
+impl TailwindInstance for AstStyle {
     fn selectors(&self, ctx: &TailwindBuilder) -> String {
         todo!()
     }
@@ -407,10 +410,10 @@ impl AstStyle {
             ["justify"] => TailwindTextAlignment::Justify.boxed(),
             // https://tailwindcss.com/docs/text-color
             ["inherit"] => TailwindTextColor::INHERIT.boxed(),
-            ["current"] => TailwindTextColor::INHERIT.boxed(),
-            ["transparent"] => TailwindTextColor::INHERIT.boxed(),
-            ["black"] => TailwindTextColor::INHERIT.boxed(),
-            ["white"] => TailwindTextColor::INHERIT.boxed(),
+            ["current"] => TailwindTextColor::CURRENT.boxed(),
+            ["transparent"] => TailwindTextColor::TRANSPARENT.boxed(),
+            ["black"] => TailwindTextColor::BLACK.boxed(),
+            ["white"] => TailwindTextColor::WHITE.boxed(),
             [color, weight] => TailwindTextColor::parse(color, weight)?.boxed(),
             _ => return syntax_error!(""),
         };
