@@ -32,11 +32,3 @@ impl TailwindFontWeight {
         Self { weight }
     }
 }
-
-impl TailwindTextColor {
-    #[inline]
-    pub fn parse(name: &str, weight: &str) -> Result<Self> {
-        let w = parse_integer(weight)?;
-        Ok(Self { color: ColorResolver::new(name, w.1) })
-    }
-}
