@@ -44,11 +44,7 @@ pub enum TailwindTextAlignment {
 #[doc = include_str ! ("font-smoothing.md")]
 #[derive(Debug, Clone)]
 pub struct TailwindTextColor {
-    color: ColorResolver,
-}
-
-impl TailwindTextColor {
-    pub const INHERIT: Self = Self { color: ColorResolver::Inherit };
+    pub(crate) color: ColorResolver,
 }
 
 #[doc = include_str ! ("font-smoothing.md")]
